//***************************************************************************//
//*                                                                         *//
//* Unit:    xml_functions                                                  *//
//* Author:  Dushkin R.V.                                                   *//
//* Date:    01.05.01                                                       *//
//*                                                                         *//
//*  This module describes all common functions, which are used in XML Par- *//
//*  sing project.                                                          *//
//*                                                                         *//
//***************************************************************************//
unit xml_functions;

//-[ INTERFACE ]---------------------------------------------------------------
interface

uses
  Sysutils;

function ParseAttributeValue (const iStr : String) : String;

function TrimSpaces (const iStr : String) : String;

//-[ IMPLEMENTATION ]----------------------------------------------------------
implementation

//-----------------------------------------------------------------------------
// [ ParseAttributeValue ]
//-----------------------------------------------------------------------------
// Parses any attribute value. In the given string ( iStr ) the attribute va-
// lue must be in the kind of '"value" ', or '"value"> ', or '"value"/> ',
// or '"value"?> '. Note, that the final space is mandatory.
//-----------------------------------------------------------------------------
function ParseAttributeValue (const iStr : String) : String;
var
  len : Integer; // Length of the given string.
begin
  len := Length (iStr);

  { DONE 5 -oDushkin R.V. -cFunction : Create the testing cycle for "empty" attribute. }
  if ((iStr = '>') or (iStr = '/>') or (iStr = '?>') or (iStr = '!>')) then
  begin
    Result := '';
  end
  else
  begin

    // This branch represents the case of '>' symbol.
    if (iStr[len - 1] = '>') then
    begin

      // This branch processes '"value"/> ' or '"value"?> ' case.
      if ((iStr[len - 2] = '/') or (iStr[len - 2] = '?')) then
      begin
        Result := Copy (iStr, 2, len - 5);
      end

      // This branch processes '"value"> ' case.
      else
      begin
        Result := Copy (iStr, 2, len - 4);
      end;
    end

    // This branch represents the case of simple attribute (no closed symbols).
    else
    begin
      Result := Copy (iStr, 2, len - 3);
    end;
  end;
end;

//-----------------------------------------------------------------------------
// [ TrimSpaces ]
//-----------------------------------------------------------------------------
//-----------------------------------------------------------------------------
{ TODO 2 -oDushkin R.V. -cFunction : Find or implement the function, which returns TRUE, if given symbol is SPACE symbol. }
function TrimSpaces (const iStr : String) : String;
var
  spaceFlag : Boolean;
  i         : Integer;
  strLength : Integer;
  tempStr   : String;
begin
  Result := '';
  spaceFlag := False;
  tempStr := Trim (iStr);
  strLength := Length (tempStr);
  i := 1;
  while (i <= strLength) do
  begin
    if (tempStr[i] <> ' ') then
    begin
      Result := Result + tempStr[i];
      spaceFlag := False;
    end
    else
    begin                                             
      if (not spaceFlag) then
      begin
        Result := Result + ' ';
        spaceFlag := True;
      end;
    end;
    i := i + 1;
  end;
end;

//-[ END ]---------------------------------------------------------------------
end.
